@@ -16,6 +16,10 @@ PDF::Iref PDF::iref_catalog( const PDF &pdf ) {
   return Iref( xref->getRootNum(), xref->getRootGen() );
 }
 
+PDF::Iref PDF::iref_info( const PDF &pdf ) {
+  return pdf.rep->info_iref;
+}
+
 int PDF::n_obj( const PDF &pdf ) {
   return pdf.rep->n_obj1;
 }
@@ -91,10 +95,28 @@ PDF::PDF::PDF( const std::string &filename_pdf )
     rep->catalog2 = rep->pdfdoc->getCatalog();
     if ( !rep->catalog2->isOk() ) throw Exc_PDF();
   }
+  {
+    Object obj;
+    { char s[] = "Info"; rep->trailer->lookupNF( s, &obj ); }
+    if ( !obj.isRef() ) throw Exc_PDF();
+    const Ref ref = obj.getRef();
+    rep->info_iref = Iref( ref.num, ref.gen );
+  }
+  {
+    rep->info_obj = new Object();
+    rep->xref->fetch(
+      rep->info_iref.i,
+      rep->info_iref.gen,
+      rep->info_obj
+    );
+    if ( !rep->info_obj->isDict() ) throw Exc_PDF();
+    rep->info = rep->info_obj->getDict();
+  }
 }
 
 PDF::PDF::~PDF() {
   delete rep->catalog_obj;
+  delete rep->info_obj;
   // For reasons this programmer does not understand, the Libpoppler PDFDoc
   // object does not seem to deallocate gracefully.  It is allowed to leak for
   // this reason.
