@@ -14,6 +14,10 @@ namespace PDF {
     PDF &pdf,
     const Page_no::PS_page_numbering &nog
   );
+  std::string add_title_to_info(
+    PDF &pdf,
+    const std::string &title
+  );
   std::string update_trailer(
     PDF &pdf,
     int n_pdf_obj,
