@@ -18,12 +18,14 @@ namespace PDF {
   std::string updator(
     PDF &pdf,
     const Page_no::PS_page_numbering &nog,
-    const TOC::Table &toc
+    const TOC::Table &toc,
+    const std::string &title = std::string()
   );
   std::string updator(
     const std::string &filename_pdf,
     const std::string &filename_ps,
-    const std::string &filename_toc
+    const std::string &filename_toc,
+    const std::string &title = std::string()
   );
 }
 
